@@ -35,6 +35,7 @@ class IProject;
 class ProjectBuildSetModel;
 class ProjectModel;
 class ProjectBaseItem;
+class ProjectChangesModel;
 
 /**
  * @class IProjectController
@@ -55,6 +56,13 @@ public:
      * @returns the model containing the projects and their items
      */
     Q_SCRIPTABLE virtual ProjectModel* projectModel() = 0;
+    
+    
+    /**
+     * @returns an instance to the model that keeps track of the state 
+     * of the files per project.
+     */
+    Q_SCRIPTABLE virtual ProjectChangesModel* changesModel() = 0;
 
     Q_SCRIPTABLE virtual ProjectBuildSetModel* buildSetModel() = 0;
 
@@ -92,6 +100,7 @@ public:
      * Returns a pretty short representation of the base path of the url, considering the currently loaded projects:
      * When the file is part of a currently loaded project, that projects name is shown as prefix instead of the
      * the full file path.
+     * The returned path always has a training slash.
      * @param format formatting used for the string
      */
     Q_SCRIPTABLE virtual QString prettyFilePath(KUrl url, FormattingOptions format = FormatHtml) const = 0;
@@ -138,7 +147,9 @@ Q_SIGNALS:
     /**
      * emitted right before a project is started to be loaded.
      * At this point all sanity checks have been done, so the project
-     * is really going to be loaded.
+     * is really going to be loaded. Will be followed by @ref projectOpened signal
+     * when loading completes or by @ref projectOpeningAborted if there are errors during loading
+     * or it is aborted.
      * @note the given project won't be very useful as it doesn't have all things
      * setup properly
      * @param url the url of the project that is about to be opened.
@@ -151,17 +162,24 @@ Q_SIGNALS:
      */
     void projectOpened( KDevelop::IProject* project );
     /**
-     * emitted when starting to close a project.
+     * emitted when starting to close a project that has been completely loaded before
+     * (the @ref projectOpened signal has been emitted).
      * @param project the project that is going to be closed.
      */
     void projectClosing( KDevelop::IProject* project );
     /**
-     * emitted when a project has been closed completely. At this
-     * point the project object is still valid, the deletion will be done
+     * emitted when a project has been closed completely.
+     * The project object is still valid, the deletion will be done
      * delayed during the next run of the event loop.
      * @param project the project that has been closed.
      */
     void projectClosed( KDevelop::IProject* project );
+    /**
+     * emitted when a project could not be loaded correctly or loading was aborted.
+     * @ref project contents may not be initialized properly.
+     * @param project the project which loading has been aborted.
+     */
+    void projectOpeningAborted( KDevelop::IProject* project );
 
     /**
      * emitted whenever the project configuration dialog accepted 
