@@ -89,12 +89,11 @@ void AbstractNavigationContext::makeLink( const QString& name, DeclarationPointe
   makeLink(name, targetId, action);
 }
 
-void AbstractNavigationContext::makeLink( const QString& name, QString targetId, const NavigationAction& action)
+QString AbstractNavigationContext::createLink(const QString& name, QString targetId, const NavigationAction& action)
 {
   if(m_shorten) {
     //Do not create links in shortened mode, it's only for viewing
-    modifyHtml() += typeHighlight(Qt::escape(name));
-    return;
+    return typeHighlight(Qt::escape(name));
   }
   
   m_links[ targetId ] = action;
@@ -109,12 +108,18 @@ void AbstractNavigationContext::makeLink( const QString& name, QString targetId,
   if( m_linkCount == m_selectedLink )
     str = "<font style=\"background-color:#f1f1f1;\" color=\"#880088\">" + str + "</font>";
 
-  modifyHtml() +=  "<a href=\"" + targetId + "\"" + ((m_linkCount == m_selectedLink && m_currentPositionLine == -1) ? QString(" name = \"currentPosition\"") : QString()) + ">" + str + "</a>";
+  QString ret =  "<a href=\"" + targetId + "\"" + ((m_linkCount == m_selectedLink && m_currentPositionLine == -1) ? QString(" name = \"currentPosition\"") : QString()) + ">" + str + "</a>";
 
   if( m_selectedLink == m_linkCount )
     m_selectedLinkAction = action;
 
   ++m_linkCount;
+  return ret;
+}
+
+void AbstractNavigationContext::makeLink( const QString& name, QString targetId, const NavigationAction& action)
+{
+  modifyHtml() += createLink(name, targetId, action);
 }
 
 void AbstractNavigationContext::clear() {
@@ -441,20 +446,28 @@ QString AbstractNavigationContext::currentHtml() const {
   return m_currentText;
 }
 
-QString AbstractNavigationContext::fontSizePrefix(bool shorten) const
+QString AbstractNavigationContext::fontSizePrefix(bool /*shorten*/) const
 {
-  if(shorten)
-    return "";
-  else
-    return "";
+  return QString();
 }
 
-QString AbstractNavigationContext::fontSizeSuffix(bool shorten) const
+QString AbstractNavigationContext::fontSizeSuffix(bool /*shorten*/) const
 {
-  if(shorten)
-    return "";
-  else
-    return "";
+  return QString();
+}
+
+QString Colorizer::operator() ( const QString& str ) const
+{
+  QString ret = "<font color=\"#" + m_color + "\">" + str + "</font>";
+
+  if( m_formatting & Fixed )
+    ret = "<tt>"+ret+"</tt>";
+  if ( m_formatting & Bold )
+    ret = "<b>"+ret+"</b>";
+  if ( m_formatting & Italic )
+    ret = "<i>"+ret+"</i>";
+
+  return ret;
 }
 
 const Colorizer AbstractNavigationContext::typeHighlight("006000");
@@ -464,7 +477,7 @@ const Colorizer AbstractNavigationContext::codeHighlight("005000");
 const Colorizer AbstractNavigationContext::propertyHighlight("009900");
 const Colorizer AbstractNavigationContext::navigationHighlight("000099");
 const Colorizer AbstractNavigationContext::importantHighlight("000000", Colorizer::Bold | Colorizer::Italic);
-const Colorizer AbstractNavigationContext::commentHighlight("000000", Colorizer::Italic);
+const Colorizer AbstractNavigationContext::commentHighlight("303030");
 const Colorizer AbstractNavigationContext::nameHighlight("000000", Colorizer::Bold);
 
 }
