@@ -82,7 +82,7 @@ void AbstractNavigationWidget::initBrowser(int height) {
   m_browser = new KTextBrowser;
   
   // since we can embed arbitrary HTML we have to make sure it stays readable by forcing a black-white palette
-  m_browser->viewport()->setPalette( QPalette( Qt::black, Qt::white ) );
+  m_browser->setPalette( QPalette( Qt::black, Qt::white ) );
 
   m_browser->setOpenLinks(false);
   m_browser->setOpenExternalLinks(false);
@@ -92,7 +92,7 @@ void AbstractNavigationWidget::initBrowser(int height) {
   layout->setMargin(0);
   setLayout(layout);
 
-  connect( m_browser, SIGNAL(anchorClicked(const QUrl&)), this, SLOT(anchorClicked(const QUrl&)) );
+  connect( m_browser, SIGNAL(anchorClicked(QUrl)), this, SLOT(anchorClicked(QUrl)) );
   
   foreach(QWidget* w, findChildren<QWidget*>())
     w->setContextMenuPolicy(Qt::NoContextMenu);
@@ -119,9 +119,12 @@ void AbstractNavigationWidget::setContext(NavigationContextPointer context, int
   if (!m_startContext)
     m_startContext = m_context;
 
+  bool wasInitial = (m_context == m_startContext);
+  
   m_context = context;
   update();
   
+  emit contextChanged(wasInitial, m_context == m_startContext);
   emit sizeHintChanged();
 }
 
@@ -215,10 +218,6 @@ void AbstractNavigationWidget::anchorClicked(const QUrl& url) {
     setContext( nextContext );
 }
 
-void AbstractNavigationWidget::keyPressEvent(QKeyEvent* event) {
-  QWidget::keyPressEvent(event);
-}
-
 void AbstractNavigationWidget::executeContextAction(QString action) {
   DUChainReadLocker lock( DUChain::lock() );
   //We may get deleted while the call to acceptLink, so make sure we don't crash in that case
