@@ -22,12 +22,12 @@
 
 #include "externalscriptitem.h"
 #include "externalscriptoutputmodel.h"
+#include "externalscriptdebug.h"
 
 #include <QFileInfo>
 #include <QApplication>
 
 #include <KProcess>
-#include <KDebug>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KShell>
@@ -53,7 +53,7 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, QObject* parent
     m_document( 0 ), m_selectionRange( KTextEditor::Range::invalid() ),
     m_showOutput( item->showOutput() )
 {
-  kDebug() << "creating external script job";
+  debug() << "creating external script job";
 
   setCapabilities( Killable );
   setStandardToolView( KDevelop::IOutputView::RunView );
@@ -95,8 +95,8 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, QObject* parent
 
     m_document = active->textDocument();
 
-    connect( m_document, SIGNAL( aboutToClose( KTextEditor::Document* ) ),
-             this, SLOT( kill() ) );
+    connect( m_document, SIGNAL(aboutToClose(KTextEditor::Document*)),
+             this, SLOT(kill()) );
 
     m_selectionRange = m_document->activeView()->selectionRange();
     m_cursorPosition = m_document->activeView()->cursorPosition();
@@ -111,35 +111,39 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, QObject* parent
   }
 
   QString command = item->command();
-  QString workingDir;
-
-  command.replace( "%i", QString::number( QCoreApplication::applicationPid() ) );
+  QString workingDir = item->workingDirectory();
+  
+  if(item->performParameterReplacement())
+    command.replace( "%i", QString::number( QCoreApplication::applicationPid() ) );
 
   if ( active ) {
     const KUrl url = active->url();
 
-    if ( url.isLocalFile() ) {
+    if ( url.isLocalFile() && workingDir.isEmpty() ) {
       ///TODO: make configurable, use fallback to project dir
       workingDir = active->url().directory();
     }
 
     ///TODO: make those placeholders escapeable
-    command.replace( "%u", KShell::quoteArg( url.pathOrUrl() ) );
+    if(item->performParameterReplacement())
+    {
+      command.replace( "%u", KShell::quoteArg( url.pathOrUrl() ) );
 
-    ///TODO: does that work with remote files?
-    QFileInfo info( url.pathOrUrl() );
+      ///TODO: does that work with remote files?
+      QFileInfo info( url.pathOrUrl() );
 
-    command.replace( "%f", KShell::quoteArg( info.filePath() ) );
-    command.replace( "%b", KShell::quoteArg( info.baseName() ) );
-    command.replace( "%n", KShell::quoteArg( info.fileName() ) );
-    command.replace( "%d", KShell::quoteArg( info.path() ) );
+      command.replace( "%f", KShell::quoteArg( info.filePath() ) );
+      command.replace( "%b", KShell::quoteArg( info.baseName() ) );
+      command.replace( "%n", KShell::quoteArg( info.fileName() ) );
+      command.replace( "%d", KShell::quoteArg( info.path() ) );
 
-    if ( active->textDocument() && active->textDocument()->activeView() && active->textDocument()->activeView()->selection() ) {
-      command.replace( "%s", KShell::quoteArg( active->textDocument()->activeView()->selectionText() ) );
-    }
+      if ( active->textDocument() && active->textDocument()->activeView() && active->textDocument()->activeView()->selection() ) {
+        command.replace( "%s", KShell::quoteArg( active->textDocument()->activeView()->selectionText() ) );
+      }
 
-    if ( KDevelop::IProject* project = KDevelop::ICore::self()->projectController()->findProjectForUrl( url ) ) {
-      command.replace( "%p", project->folder().pathOrUrl() );
+      if ( KDevelop::IProject* project = KDevelop::ICore::self()->projectController()->findProjectForUrl( url ) ) {
+        command.replace( "%p", project->folder().pathOrUrl() );
+      }
     }
   }
 
@@ -148,17 +152,17 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, QObject* parent
     m_proc->setWorkingDirectory( workingDir );
   }
   m_lineMaker = new KDevelop::ProcessLineMaker( m_proc, this );
-  connect( m_lineMaker, SIGNAL( receivedStdoutLines( QStringList ) ),
-           model, SLOT( appendStdoutLines( QStringList ) ) );
-  connect( m_lineMaker, SIGNAL( receivedStderrLines( QStringList ) ),
-           model, SLOT( appendStderrLines( QStringList ) ) );
-  connect( m_proc, SIGNAL( error( QProcess::ProcessError ) ),
-           SLOT( processError( QProcess::ProcessError ) ) );
-  connect( m_proc, SIGNAL( finished( int, QProcess::ExitStatus ) ),
-           SLOT( processFinished( int, QProcess::ExitStatus ) ) );
+  connect( m_lineMaker, SIGNAL(receivedStdoutLines(QStringList)),
+           model, SLOT(appendStdoutLines(QStringList)) );
+  connect( m_lineMaker, SIGNAL(receivedStderrLines(QStringList)),
+           model, SLOT(appendStderrLines(QStringList)) );
+  connect( m_proc, SIGNAL(error(QProcess::ProcessError)),
+           SLOT(processError(QProcess::ProcessError)) );
+  connect( m_proc, SIGNAL(finished(int,QProcess::ExitStatus)),
+           SLOT(processFinished(int,QProcess::ExitStatus)) );
 
   // Now setup the process parameters
-  kDebug() << "setting command:" << command;
+  debug() << "setting command:" << command;
 
   if ( m_errorMode == ExternalScriptItem::ErrorMergeOutput ) {
     m_proc->setOutputChannelMode( KProcess::MergedChannels );
@@ -172,7 +176,7 @@ ExternalScriptJob::ExternalScriptJob( ExternalScriptItem* item, QObject* parent
 
 void ExternalScriptJob::start()
 {
-  kDebug() << "launching?" << m_proc;
+  debug() << "launching?" << m_proc;
 
   if ( m_proc ) {
     if ( m_showOutput ) {
@@ -320,7 +324,7 @@ void ExternalScriptJob::processFinished( int exitCode , QProcess::ExitStatus sta
         appendLine( i18n( "*** Crashed with return code: %1 ***", QString::number( exitCode ) ) );
   }
 
-  kDebug() << "Process done";
+  debug() << "Process done";
 
   emitResult();
 }
@@ -336,7 +340,7 @@ void ExternalScriptJob::processError( QProcess::ProcessError error )
     emitResult();
   }
 
-  kDebug() << "Process error";
+  debug() << "Process error";
 }
 
 void ExternalScriptJob::appendLine( const QString& l )
