@@ -30,17 +30,19 @@ class TestCore;
 class ProjectLoadTest : public QObject
 {
 Q_OBJECT
-  void self();
+
 private slots:
+  void initTestCase();
+  void cleanupTestCase();
   void init();
-  void cleanup();
 
   void addRemoveFiles();
   void addLotsOfFiles();
   void addMultipleJobs();
 
-private:
-  KDevelop::TestCore* m_core;
+  void raceJob();
+
+  void addDuringImport();
 };
 
 #endif
