@@ -243,10 +243,11 @@ QMenu* GrepDialog::createSyncButtonMenu()
 
 void GrepDialog::directoryChanged(const QString& dir)
 {
-    setEnableProjectBox(false);
     KUrl currentUrl = dir;
-    if( !currentUrl.isValid() )
+    if( !currentUrl.isValid() ) {
+        setEnableProjectBox(false);
         return;
+    }
     
     bool projectAvailable = true;
     
@@ -286,7 +287,7 @@ void GrepDialog::templateTypeComboActivated(int index)
 void GrepDialog::setEnableProjectBox(bool enable)
 {
     limitToProjectCheck->setEnabled(enable);
-    if (!enable) limitToProjectCheck->setChecked(false);
+    limitToProjectLabel->setEnabled(enable);
 }
 
 void GrepDialog::setPattern(const QString &pattern)
@@ -331,6 +332,7 @@ QString GrepDialog::excludeString() const
 
 bool GrepDialog::useProjectFilesFlag() const
 {
+    if (!limitToProjectCheck->isEnabled()) return false;
     return limitToProjectCheck->isChecked();
 }
 
