@@ -31,10 +31,13 @@
 
 #include <KUser>
 
+#include <KAction>
+#include <KShortcut>
+
 #include "snippetstore.h"
 
 SnippetRepository::SnippetRepository(const QString& file)
- : QStandardItem(i18n("<empty repository>")), m_file(file)
+ : QStandardItem(i18n("<empty repository>")), m_file(file), m_registeredScript(0)
 {
     setIcon( KIcon("folder") );
     bool activated = SnippetStore::self()->getConfig().readEntry<QStringList>("enabledRepositories", QStringList()).contains(file);
@@ -108,6 +111,35 @@ void SnippetRepository::setLicense(const QString& license)
     m_license = license;
 }
 
+QString SnippetRepository::completionNamespace() const
+{
+    return m_namespace;
+}
+
+void SnippetRepository::setCompletionNamespace(const QString& completionNamespace)
+{
+    m_namespace = completionNamespace;
+}
+
+QString SnippetRepository::script() const
+{
+    return m_script;
+}
+
+KTextEditor::TemplateScript* SnippetRepository::registeredScript() const
+{
+    return m_registeredScript;
+}
+
+void SnippetRepository::setScript(const QString& script)
+{
+    m_script = script;
+    if ( m_registeredScript ) {
+        SnippetStore::self()->unregisterScript(m_registeredScript);
+    }
+    m_registeredScript = SnippetStore::self()->registerScript(m_script);
+}
+
 void SnippetRepository::remove()
 {
     QFile::remove(m_file);
@@ -129,7 +161,10 @@ void SnippetRepository::save()
     ///based on the code from snippets_tng/lib/completionmodel.cpp
     ///@copyright 2009 Joseph Wenninger <jowenn@kde.org>
     /*
-    <snippets name="Testsnippets" filetype="*" authors="Joseph Wenninger" license="BSD">
+    <snippets name="Testsnippets" filetype="*" authors="Joseph Wenninger" license="BSD" namespace="test::">
+        <script>
+            JavaScript
+        </script>
         <item>
             <displayprefix>prefix</displayprefix>
             <match>test1</match>
@@ -150,9 +185,12 @@ void SnippetRepository::save()
     root.setAttribute("filetypes", m_filetypes.isEmpty() ? "*" : m_filetypes.join(";"));
     root.setAttribute("authors", m_authors);
     root.setAttribute("license", m_license);
+    root.setAttribute("namespace", m_namespace);
 
     doc.appendChild(root);
 
+    addAndCreateElement(doc, root, "script", m_script);
+
     for ( int i = 0; i < rowCount(); ++i ) {
         Snippet* snippet = dynamic_cast<Snippet*>(child(i));
         if ( !snippet ) {
@@ -189,6 +227,19 @@ void SnippetRepository::save()
     outfile.write(doc.toByteArray());
     outfile.close();
     m_file = outname;
+
+    // save shortcuts
+    KConfigGroup config = SnippetStore::self()->getConfig().group("repository " + m_file);
+    for ( int i = 0; i < rowCount(); ++i ) {
+        Snippet* snippet = dynamic_cast<Snippet*>(child(i));
+        if ( !snippet ) {
+            continue;
+        }
+        config.writeEntry("shortcut " + snippet->text(),
+                          QStringList() << snippet->action()->shortcut().primary().toString()
+                                        << snippet->action()->shortcut().alternate().toString());
+    }
+    config.sync();
 }
 
 void SnippetRepository::slotParseFile()
@@ -226,6 +277,10 @@ void SnippetRepository::slotParseFile()
     setAuthors(docElement.attribute("authors"));
     setFileTypes(docElement.attribute("filetypes").split(';', QString::SkipEmptyParts));
     setText(docElement.attribute("name"));
+    setCompletionNamespace(docElement.attribute("namespace"));
+
+    // load shortcuts
+    KConfigGroup config = SnippetStore::self()->getConfig().group("repository " + m_file);
 
     // parse children, i.e. <item>'s
     const QDomNodeList& nodes = docElement.childNodes();
@@ -235,6 +290,9 @@ void SnippetRepository::slotParseFile()
             continue;
         }
         const QDomElement& item = node.toElement();
+        if ( item.tagName() == "script" ) {
+            setScript(item.text());
+        }
         if ( item.tagName() != "item" ) {
             continue;
         }
@@ -263,6 +321,13 @@ void SnippetRepository::slotParseFile()
             delete snippet;
             continue;
         } else {
+            const QStringList shortcuts = config.readEntry("shortcut " + snippet->text(), QStringList());
+            if ( shortcuts.count() >= 2 ) {
+                KShortcut shortcut;
+                shortcut.setPrimary(shortcuts.value(0));
+                shortcut.setAlternate(shortcuts.value(1));
+                snippet->action()->setShortcut(shortcut);
+            }
             appendRow(snippet);
         }
     }
