@@ -21,6 +21,7 @@
 
 #include <qtest_kde.h>
 #include <tests/autotestshell.h>
+#include <tests/testcore.h>
 
 #include <kglobal.h>
 #include <kdebug.h>
@@ -34,19 +35,19 @@
 
 Q_DECLARE_METATYPE( KDevelop::ISession* )
 
-using KDevelop::SessionController;
-using KDevelop::ISession;
-using KDevelop::AutoTestShell;
-using KDevelop::Session;
-using KDevelop::Core;
+using namespace KDevelop;
 
 using QTest::kWaitForSignal;
 
 //////////////////// Helper Functions ////////////////////////////////////////
 
-void verifySessionDir( Session* s, bool exists = true )
+QString sessionDir( ISession* s )
+{
+    return SessionController::sessionDirectory() + "/" + s->id().toString();
+}
+
+void verifySessionDir( const QString& sessiondir, const QString& name, bool exists )
 {
-    QString sessiondir = SessionController::sessionDirectory() + "/" + s->id().toString();
     if( exists ) 
     {
         kDebug() << "checking existing session" << sessiondir;
@@ -54,19 +55,24 @@ void verifySessionDir( Session* s, bool exists = true )
         QVERIFY( QFileInfo( sessiondir ).isDir() );
         QVERIFY( QFileInfo( sessiondir+"/sessionrc" ).exists() );
         KSharedConfig::Ptr cfg = KSharedConfig::openConfig( sessiondir+"/sessionrc" );
-        QCOMPARE( s->name(), cfg->group("").readEntry( Session::cfgSessionNameEntry, "" ) );
+        QCOMPARE( name, cfg->group("").readEntry( Session::cfgSessionNameEntry, "" ) );
     } else {
         kDebug() << "checking not-existing dir: " << sessiondir;
         QVERIFY( !QFileInfo( sessiondir ).exists() );
     }
 }
 
+void verifySessionDir( ISession* s, bool exists = true )
+{
+    verifySessionDir(sessionDir(s), s->name(), exists);
+}
+
 ////////////////////// Fixture ///////////////////////////////////////////////
 
 void SessionControllerTest::initTestCase()
 {
     AutoTestShell::init();
-    Core::initialize( 0, KDevelop::Core::NoUi );
+    TestCore::initialize(Core::NoUi);
     m_core = Core::self();
     qRegisterMetaType<KDevelop::ISession*>();
 }
@@ -83,12 +89,8 @@ void SessionControllerTest::cleanupTestCase()
         if (m_sessionCtrl->activeSession()->name() != name)
             m_sessionCtrl->deleteSession( name );
     }
-    // Need to cleanup this directory manually, because SessionController (rightfully) doesn't
-    // allow to delete the active session
-    Session* s = static_cast<Session*>( Core::self()->activeSession() );
-    KIO::NetAccess::del( SessionController::sessionDirectory() + "/" + s->id().toString(), 0 );
-    KGlobal::config()->group( SessionController::cfgSessionGroup() ).deleteEntry( SessionController::cfgActiveSessionEntry() );
-    KGlobal::config()->group( SessionController::cfgSessionGroup() ).sync();
+
+    TestCore::shutdown();
 }
 
 void SessionControllerTest::createSession_data()
@@ -116,7 +118,7 @@ void SessionControllerTest::renameSession()
     KDevelop::Session *s = m_sessionCtrl->createSession( sessionName );
     QCOMPARE( sessionName, s->name() );
     verifySessionDir( s );
-    QSignalSpy spy(s, SIGNAL(nameChanged(const QString&, const QString&)));
+    QSignalSpy spy(s, SIGNAL(nameChanged(QString,QString)));
     s->setName( newSessionName );
     QCOMPARE( newSessionName, s->name() );
     
@@ -136,7 +138,7 @@ void SessionControllerTest::canRenameActiveSession()
     KDevelop::Session *s = m_sessionCtrl->createSession( sessionName );
     QCOMPARE( sessionName, s->name() );
     m_sessionCtrl->loadSession( sessionName );
-    QSignalSpy spy(s, SIGNAL(nameChanged(const QString&, const QString&)));
+    QSignalSpy spy(s, SIGNAL(nameChanged(QString,QString)));
     s->setName( newSessionName );
     QCOMPARE( newSessionName, s->name() );
     
@@ -156,7 +158,7 @@ void SessionControllerTest::deleteSession()
     Session* s = m_sessionCtrl->createSession( sessionName );
     QCOMPARE( sessionCount+1, m_sessionCtrl->sessionNames().count() );
     verifySessionDir( s );
-    QSignalSpy spy(m_sessionCtrl, SIGNAL(sessionDeleted(const QString&)));
+    QSignalSpy spy(m_sessionCtrl, SIGNAL(sessionDeleted(QString)));
     m_sessionCtrl->deleteSession( sessionName );
     QCOMPARE( sessionCount, m_sessionCtrl->sessionNames().count() );
 
@@ -204,5 +206,20 @@ void SessionControllerTest::readFromConfig()
     QCOMPARE(grp.readEntry( "TestEntry", "" ), QString( "Test1" ) );
 }
 
+void SessionControllerTest::temporary()
+{
+    ISession* s = Core::self()->activeSession();
+    s->setTemporary(true);
+    const QString oldName = s->name();
+    const QString dir = sessionDir(s);
+
+    verifySessionDir(s, true);
+    Core::self()->sessionController()->cleanup();
+    verifySessionDir(dir, oldName, false);
+    Core::self()->sessionController()->initialize(oldName);
+    QCOMPARE(Core::self()->activeSession()->name(), oldName);
+    // dir / UID can be different, hence don't verifySessionDir
+}
+
 QTEST_KDEMAIN( SessionControllerTest, GUI)
 #include "sessioncontrollertest.moc"
