@@ -75,8 +75,16 @@ public:
     QString iconName() const;
     void setIconName(const QString &iconName);
 
-    /**Adds the @p view to the list of views at the given area index.*/
-    void addView(View *view, AreaIndex *index);
+
+    /**Adds the @p view to the list of views at the given area index,
+    after the given view @p after.
+
+    If @p after == 0  &&  controller()->openAfterCurrent():
+        @p view is inserted after current view
+    If @p after == 0  &&  !controller()->openAfterCurrent():
+        @p view is inserted at the last position.
+    */
+    void addView(View *view, AreaIndex *index, View *after = 0);
 
     /**Adds the @p view to the list of views at the current area index.*/
     void addView(View *view, View *after = 0);
@@ -99,8 +107,9 @@ public:
 
     /** Removes all views from this area and deletes them.
       * If an open document has changes, and it is the last view of that document,
-      * the user may push 'Cancel', and the view will stay active. */
-    void clearViews();
+      * the user may push 'Cancel', and the view will stay active.
+      * @param silent If this is true, the user is never asked for feedback. */
+    void clearViews(bool silent = false);
 
     /**
      * Returns the view that was last stored through setActiveView(view), or zero
@@ -117,8 +126,10 @@ public:
       * Closes the document if it is the last view.
       * Does allow breaking the closing process.
       * If it is the last view of the document that has changes, and the user pushed 'Cancel',
-      * false will be returned, and the view will not be closed. */
-    bool closeView(View* view);
+      * false will be returned, and the view will not be closed. 
+      * @param silent If this is false, the user will be asked for feedback. Otherwise he won't.
+      */
+    bool closeView(View* view, bool silent = false);
     
     /**@return the index of view or 0 if it can not be found.*/
     AreaIndex *indexOf(View *view);
@@ -149,8 +160,8 @@ public:
        added with 'addToolView', however, this method can be used
        to guess a set of tool views that make most sense to be added.  */
     bool wantToolView(const QString& id);
-    void setShownToolView(Sublime::Position pos, const QString& id);
-    QString shownToolView(Sublime::Position pos) const;
+    void setShownToolViews(Sublime::Position pos, const QStringList& ids);
+    QStringList shownToolViews(Sublime::Position pos) const;
     void setDesiredToolViews(
         const QMap<QString, Sublime::Position>& desiredToolViews);
 
@@ -169,7 +180,7 @@ public:
     ///within Area.
     ///The actual view management has to be implemented in the entity that knows more
     ///about possible views, documents, etc. (kdevplatform/shell)
-    ///@warning (KDevelop): Before calling this, make sure that all views are saved!
+    ///@warning (KDevelop): Before calling this, make sure that all views are saved! (see IDocumentController::saveAllDocumentsForWindow)
     void setWorkingSet(QString name);
     
     /**Walker mode to determine the behavior of area walkers.*/
